import { InjectionToken } from '@angular/core';
import { AnyType } from '../common/core.types';
import { IMockRenderOptions, MockedComponentFixture } from './types';
interface MockRenderFactory<C = any, F extends keyof any = keyof C> {
    bindings: keyof F;
    declaration: AnyType<never>;
    <T extends Record<F, any>>(params?: Partial<T>, detectChanges?: boolean): MockedComponentFixture<C, T>;
}
/**
 * @see https://ng-mocks.sudo.eu/api/MockRender#factory
 */
declare function MockRenderFactory<MComponent>(template: InjectionToken<MComponent>, bindings?: undefined | null, options?: IMockRenderOptions): MockRenderFactory<MComponent, never>;
/**
 * @see https://ng-mocks.sudo.eu/api/MockRender#factory
 */
declare function MockRenderFactory<MComponent>(template: AnyType<MComponent>, bindings: undefined | null, options?: IMockRenderOptions): MockRenderFactory<MComponent, keyof MComponent>;
/**
 * @see https://ng-mocks.sudo.eu/api/MockRender#factory
 */
declare function MockRenderFactory<MComponent, TKeys extends keyof any>(template: AnyType<MComponent>, bindings: TKeys[], options?: IMockRenderOptions): MockRenderFactory<MComponent, TKeys>;
/**
 * @see https://ng-mocks.sudo.eu/api/MockRender#factory
 */
declare function MockRenderFactory<MComponent, TKeys extends keyof any = keyof any>(template: AnyType<MComponent>, bindings: TKeys, options?: IMockRenderOptions): MockRenderFactory<MComponent, TKeys>;
/**
 * Without params we should not autocomplete any keys of any types.
 *
 * @see https://ng-mocks.sudo.eu/api/MockRender#factory
 */
declare function MockRenderFactory<MComponent>(template: AnyType<MComponent>): MockRenderFactory<MComponent, keyof MComponent>;
/**
 * An empty string does not have point.
 *
 * @see https://ng-mocks.sudo.eu/api/MockRender#factory
 */
declare function MockRenderFactory(template: ''): MockRenderFactory<void, never>;
/**
 * Without params we should not autocomplete any keys of any types.
 *
 * @see https://ng-mocks.sudo.eu/api/MockRender#factory
 */
declare function MockRenderFactory<MComponent = void>(template: string): MockRenderFactory<MComponent>;
/**
 * @see https://ng-mocks.sudo.eu/api/MockRender#factory
 */
declare function MockRenderFactory<MComponent = void, TKeys extends keyof any = keyof any>(template: string, bindings?: undefined | null, options?: IMockRenderOptions): MockRenderFactory<MComponent, TKeys>;
export { MockRenderFactory };
